==> ssp-center-api-0.5.56-flj-20190820.084121-5-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteSlotSckService.java <==
/**
 * Project Name:ssp-center-api File Name:RemoteSlotSckService.java Package Name:cn.com.duiba.tuia.ssp.center.api.remote
 * Date:2017年11月3日下午2:42:16 Copyright (c) 2017, duiba.com.cn All Rights Reserved.
 */

package cn.com.duiba.tuia.ssp.center.api.remote;

import java.util.List;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.ssp.center.api.dto.SlotSck;
import cn.com.duiba.wolf.dubbo.DubboResult;

/**
 * ClassName:RemoteSlotSckService <br/>
 * Function: 广告位素材库关联service<br/>
 * Date: 2017年11月3日 下午2:42:16 <br/>
 * 
 * @author Administrator
 * @version
 * @since JDK 1.6
 * @see
 */
@AdvancedFeignClient
public interface RemoteSlotSckService {

    DubboResult<Integer> insertBatch(List<SlotSck> slotScks);


    DubboResult<Integer> addPassSck(List<SlotSck> slotScks);

    DubboResult<Integer> removePassSck(Long slotId,List<Long> sckIds);


    DubboResult<List<SlotSck>> selectBySlotId(Long slotId);


    DubboResult<List<SlotSck>> selectBySlotIdAndCheckStatus(Long slotId, Integer checkStatus);

    /**
     * 根据广告位获取素材（包含推荐的ctr最高的素材）
     *
     * @param slotId 广告位id
     * @return 返回素材列表（定制列表小于50个 用ctr最高的素材补全50个）
     */
    List<SlotSck> selectWithRecommendSckBySlotId(Long slotId);

    List<SlotSck> selectMediaSckBySlotId(Long slotId);

    /**
     * 查询所有的广告位定制素材，包含删除
     * @param slotId
     * @return
     */
    List<SlotSck> selectAllBySlotId(Long slotId);

    DubboResult<Integer> deleteBySlotId(Long slotId);

	/**
	 * 广告位是否有素材
	 * @param slotIds 广告id集合
	 * @return 返回有素材的id集合
	 */
	List<Long> hasMaterial(List<Long> slotIds);


    Integer updateDeleteStatus(Long slotId, Integer status, List<Long> sckIds);

    Integer updateDownloadNum(Long slotId, Long sckId);

    Integer updateSort(List<SlotSck> slotSckList);

    Integer updateSlotSck(List<SlotSck> slotSckList);
}

==> ssp-center-api-0.5.59-flj-20190821.014609-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteSlotSckService.java <==
/**
 * Project Name:ssp-center-api File Name:RemoteSlotSckService.java Package Name:cn.com.duiba.tuia.ssp.center.api.remote
 * Date:2017年11月3日下午2:42:16 Copyright (c) 2017, duiba.com.cn All Rights Reserved.
 */

package cn.com.duiba.tuia.ssp.center.api.remote;

import java.util.List;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.ssp.center.api.dto.SlotSck;
import cn.com.duiba.wolf.dubbo.DubboResult;

/**
 * ClassName:RemoteSlotSckService <br/>
 * Function: 广告位素材库关联service<br/>
 * Date: 2017年11月3日 下午2:42:16 <br/>
 * 
 * @author Administrator
 * @version
 * @since JDK 1.6
 * @see
 */
@AdvancedFeignClient
public interface RemoteSlotSckService {

    DubboResult<Integer> insertBatch(List<SlotSck> slotScks);


    DubboResult<Integer> addPassSck(List<SlotSck> slotScks);

    DubboResult<Integer> removePassSck(Long slotId,List<Long> sckIds);


    DubboResult<List<SlotSck>> selectBySlotId(Long slotId);


    DubboResult<List<SlotSck>> selectBySlotIdAndCheckStatus(Long slotId, Integer checkStatus);

    /**
     * 根据广告位获取素材（包含推荐的ctr最高的素材）
     *
     * @param slotId 广告位id
     * @return 返回素材列表（定制列表小于50个 用ctr最高的素材补全50个）
     */
    List<SlotSck> selectWithRecommendSckBySlotId(Long slotId);

    List<SlotSck> selectMediaSckBySlotId(Long slotId);

    /**
     * 查询所有的广告位定制素材，包含删除
     * @param slotId
     * @return
     */
    List<SlotSck> selectAllBySlotId(Long slotId);

    DubboResult<Integer> deleteBySlotId(Long slotId);

	/**
	 * 广告位是否有素材
	 * @param slotIds 广告id集合
	 * @return 返回有素材的id集合
	 */
	List<Long> hasMaterial(List<Long> slotIds);


    Integer updateDeleteStatus(Long slotId, Integer status, List<Long> sckIds);

    Integer updateDownloadNum(Long slotId, Long sckId);

    Integer updateSort(List<SlotSck> slotSckList);

    Integer updateSlotSck(List<SlotSck> slotSckList);

    /**
     * 获取配置的素材信息，包含文案
     * @param slotId 广告位ID
     * @param sckType 广告位素材类型
     * @return 素材信息
     */
    List<SlotSck> selectBySlotIdAndSckType(Long slotId, Integer sckType);

    List<SlotSck> selectBySlotIdAndSckTypeAndCheckStatus(Long slotId, Integer sckType, Integer checkStatus);
}
